# Copyright © 2021 Arrikto Inc.  All Rights Reserved.

"""Kale SDK.

This script trains an ML pipeline to solve a binary classification task.
"""

from kale.sdk import pipeline, step
from sklearn.datasets import make_classification
from sklearn.linear_model import LogisticRegression
from sklearn.model_selection import train_test_split


@step(name="data_loading")
def load(random_state):
    """Create a random dataset for binary classification."""
    rs = int(random_state)
    x, y = make_classification(random_state=rs)
    return x, y


@step(name="data_split",
      deploy_config={"limits": {"cpu": "100m", "memory": "1Gi"}})
def split(x, y):
    """Split the data into train and test sets."""
    x, x_test, y, y_test = train_test_split(x, y, test_size=0.1)
    return x, x_test, y, y_test


@step(name="model_training",
      deploy_config={"labels": {"training-step": "true"}})
def train(x, x_test, y, training_iterations):
    """Train a Logistic Regression model."""
    iters = int(training_iterations)
    model = LogisticRegression(max_iter=iters)
    model.fit(x, y)
    print(model.predict(x_test))


pod_ip_env = {"name": "MY_POD_IP",
              "valueFrom": {"fieldRef": {"fieldPath": "status.podIP"}}}


@pipeline(name="binary-classification", experiment="kale-tutorial",
          deploy_config={"env": [pod_ip_env]})
def ml_pipeline(rs=42, iters=100):
    """Run the ML pipeline."""
    x, y = load(rs)
    x, x_test, y, y_test = split(x, y)
    train(x, x_test, y, iters)


if __name__ == "__main__":
    ml_pipeline(rs=42, iters=100)
